==> elgg-2.3.5.zip: elgg-2.3.5/mod/bookmarks/languages/eu_es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Laster-markak",
	'bookmarks:add' => "Laster-marka bat gehitu",
	'bookmarks:edit' => "Laster-marka editatu",
	'bookmarks:owner' => "%s-ren laster-marka",
	'bookmarks:friends' => "Lagunen laster-marka",
	'bookmarks:everyone' => "Gune osoko laster-markak",
	'bookmarks:this' => "Orrialde honen laster-marka egin",
	'bookmarks:this:group' => "Laster-marka %s-en",
	'bookmarks:bookmarklet' => "Laster-markatzailea lortu",
	'bookmarks:bookmarklet:group' => "Talde laster-marka lortu",
	'bookmarks:inbox' => "Laster-marken sarrera-ontzia",
	'bookmarks:with' => "Honekin partekatu",
	'bookmarks:new' => "Laster-marka berria",
	'bookmarks:address' => "Laster-markaren helbidea",
	'bookmarks:none' => 'Ez dago laster-markarik',

	'bookmarks:notify:summary' => 'Laster-marka berria %s deitua',
	'bookmarks:notify:subject' => 'Laster-marka berria: %s',
	'bookmarks:notify:body' =>
'%s-ek laster-marka berria gehitu du: %s

Helbidea: %s

%s

Ikusi eta iruzkina idatzi laster-markan:
%s
',

	'bookmarks:delete:confirm' => "Ziur al zaude baliabide hau ezabatu nahi duzula?",

	'bookmarks:numbertodisplay' => 'Erakutsiko den laster-marka kopurua',

	'bookmarks:shared' => "Laster-marka eginda",
	'bookmarks:visit' => "Baliabidea bisitatu",
	'bookmarks:recent' => "Azken laster-markak",

	'river:create:object:bookmarks' => '%s-ek %s laster-marka egin du',
	'river:comment:object:bookmarks' => '%s-ek %s laster-markan iruzkina idatzi du',
	'bookmarks:river:annotate' => 'iruzkin bat laster-marka honetan',
	'bookmarks:river:item' => 'elementua',

	'item:object:bookmarks' => 'Laster-markak',

	'bookmarks:group' => 'Talde laster-markak',
	'bookmarks:enablebookmarks' => 'Talde laster-markak gaitu',
	'bookmarks:nogroup' => 'Talde honek oraindik ez du laster-markarik',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Zure azken laster-markak erakutsi.",

	'bookmarks:bookmarklet:description' =>
			"Laster-markatzailea zure nabigatzaileko url barran gordetzen den botoi berezia da. Honekin webean aurkitzen duzun edozein baliabide zure laster-markan gordetzea ahalbidetzen du eta zure lagunekin partekatu, hau aukerazkoa izanik. Hau konfiguratzeko, arrastratu beheko botoia zure nabigatzailearen url barran:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Internet Explorer erabiltzen ari bazara, laster-markatzaile ikonoan eskuineko botoiarekin klik egin beharko duzu, \"gehitu gogokoetara\" aukeratu eta ondoren url barra.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Bisitatzen duzun edozein orrialde laster-marka bihurtu dezakezu zure nabigatzailean beti agertuko den botoian klikatuz.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Zure elementua arrakastaz laster-marka bezala markatu da.",
	'bookmarks:delete:success' => "Zure laster-marka ezabatu da.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Zure laster-marka ezin da gorde. Ziurtatu izenburua eta helbidea sartu duzula eta saiatu berriz.",
	'bookmarks:save:invalid' => "Laster-markaren helbidea ez da egokia eta ezin da gorde.",
	'bookmarks:delete:failed' => "Ezin da zure laster-marka ezabatu. Saiatu berriro mesedez.",
	'bookmarks:unknown_bookmark' => 'Ezin da zehaztutako laster-marka aurkitu',
);

==> elgg-2.3.17.zip: elgg-2.3.17/mod/bookmarks/languages/eu_es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Laster-markak",
	'bookmarks:add' => "Laster-marka bat gehitu",
	'bookmarks:edit' => "Laster-marka editatu",
	'bookmarks:owner' => "%s-ren laster-marka",
	'bookmarks:friends' => "Lagunen laster-marka",
	'bookmarks:everyone' => "Gune osoko laster-markak",
	'bookmarks:this' => "Orrialde honen laster-marka egin",
	'bookmarks:this:group' => "Laster-marka %s-en",
	'bookmarks:bookmarklet' => "Laster-markatzailea lortu",
	'bookmarks:bookmarklet:group' => "Talde laster-marka lortu",
	'bookmarks:inbox' => "Laster-marken sarrera-ontzia",
	'bookmarks:address' => "Laster-markaren helbidea",
	'bookmarks:none' => 'Ez dago laster-markarik',

	'bookmarks:notify:summary' => 'Laster-marka berria %s deitua',
	'bookmarks:notify:subject' => 'Laster-marka berria: %s',
	'bookmarks:notify:body' =>
'%s-ek laster-marka berria gehitu du: %s

Helbidea: %s

%s

Ikusi eta iruzkina idatzi laster-markan:
%s
',

	'bookmarks:delete:confirm' => "Ziur al zaude baliabide hau ezabatu nahi duzula?",

	'bookmarks:numbertodisplay' => 'Erakutsiko den laster-marka kopurua',

	'river:create:object:bookmarks' => '%s-ek %s laster-marka egin du',
	'river:comment:object:bookmarks' => '%s-ek %s laster-markan iruzkina idatzi du',
	'bookmarks:river:annotate' => 'iruzkin bat laster-marka honetan',
	'bookmarks:river:item' => 'elementua',

	'item:object:bookmarks' => 'Laster-markak',

	'bookmarks:group' => 'Talde laster-markak',
	'bookmarks:enablebookmarks' => 'Talde laster-markak gaitu',
	'bookmarks:nogroup' => 'Talde honek oraindik ez du laster-markarik',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Zure azken laster-markak erakutsi.",

	'bookmarks:bookmarklet:description' =>
			"A bookmarklet is a special kind of button you save to your browser's links bar. This allows you to save any resource you find on the web to your bookmarks. To set it up, drag the button below to your browser's links bar:",

	'bookmarks:bookmarklet:descriptionie' =>
			"Internet Explorer erabiltzen ari bazara, laster-markatzaile ikonoan eskuineko botoiarekin klik egin beharko duzu, \"gehitu gogokoetara\" aukeratu eta ondoren url barra.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Bisitatzen duzun edozein orrialde laster-marka bihurtu dezakezu zure nabigatzailean beti agertuko den botoian klikatuz.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Zure elementua arrakastaz laster-marka bezala markatu da.",
	'bookmarks:delete:success' => "Zure laster-marka ezabatu da.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Zure laster-marka ezin da gorde. Ziurtatu izenburua eta helbidea sartu duzula eta saiatu berriz.",
	'bookmarks:save:invalid' => "Laster-markaren helbidea ez da egokia eta ezin da gorde.",
	'bookmarks:delete:failed' => "Ezin da zure laster-marka ezabatu. Saiatu berriro mesedez.",
	'bookmarks:unknown_bookmark' => 'Ezin da zehaztutako laster-marka aurkitu',
);
